yenta.tasks package
===================

Submodules
----------

yenta.tasks.Task module
-----------------------

.. automodule:: yenta.tasks.Task
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: yenta.tasks
   :members:
   :undoc-members:
   :show-inheritance:
